@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.25.0';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.25.1';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -184,7 +184,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.25.0
+version 0.25.1
 
 =head1 DESCRIPTION
 
@@ -275,7 +275,7 @@ his distributions. It's roughly equivalent to
 
     [RunExtraTests]
     [Test::UnusedVars]
-    [Test::PAUSE::Permisions]
+    [Test::PAUSE::Permissions]
 
     [DOAP]
     process_changes = 1
